@@ -2,6 +2,7 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
+from builtins import str
 from future import standard_library
 standard_library.install_aliases()
 from builtins import object
@@ -22,6 +23,9 @@ class DatastoreOperation(object):
         self.error = error
         self.response = response
 
+    def __repr__(self)       :
+        return str(self.to_repr())
+
     @classmethod
     def from_repr(cls, data                )                        :
         return cls(data['name'], data.get('done', False), data.get('metadata'),
